!
!-------------------------- Default Units for Model ---------------------------!
!
!
defaults units  &
   length = mm  &
   angle = deg  &
   force = newton  &
   mass = kg  &
   time = sec
!
defaults units  &
   coordinate_system_type = cartesian  &
   orientation_type = body313
!
!------------------------ Default Attributes for Model ------------------------!
!
!
defaults attributes  &
   inheritance = bottom_up  &
   icon_visibility = on  &
   grid_visibility = off  &
   size_of_icons = 50.0  &
   spacing_for_grid = 1000.0
!
!------------------------------ Adams/View Model ------------------------------!
!
!
model create  &
   model_name = Welle_1D_270
!
view erase
!
!--------------------------------- Materials ----------------------------------!
!
!
material create  &
   material_name = .Welle_1D_270.steel  &
   adams_id = 1  &
   youngs_modulus = 2.07E+005  &
   poissons_ratio = 0.29  &
   density = 7.801E-006
!
!-------------------------------- Rigid Parts ---------------------------------!
!
! Create parts and their dependent markers and graphics
!
!----------------------------------- ground -----------------------------------!
!
!
! ****** Ground Part ******
!
defaults model  &
   part_name = ground
!
defaults coordinate_system  &
   default_coordinate_system = .Welle_1D_270.ground
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Welle_1D_270.ground.MARKER_2  &
   adams_id = 2  &
   location = 270.0, 0.0, 0.0  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .Welle_1D_270.ground.MARKER_4  &
   adams_id = 4  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Welle_1D_270.ground  &
   material_type = .Welle_1D_270.steel
!
part attributes  &
   part_name = .Welle_1D_270.ground  &
   name_visibility = off
!
!------------------------------ Flexible Bodies -------------------------------!
!
! Create flexible bodies and their dependent markers
!
!-------------------------------- FLEX_BODY_1 ---------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Welle_1D_270.ground
!
part create flexible_body name_and_position  &
   flexible_body_name = .Welle_1D_270.FLEX_BODY_1  &
   adams_id = 1  &
   modal_neutral_file_name =   &
                             "D:/Users/Hanns/Eigene Dokumente/Maschinenbau TU/Projektarbeit/Arbeitsordner/Patran/1d_welle_270_0.mnf"  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
part create flexible_body modal_ics  &
   flexible_body_name = .Welle_1D_270.FLEX_BODY_1  &
   selected_modes = 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,  &
                    22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,  &
                    36, 37, 38
!
part modify flexible_body deformed_mode_display  &
   flexible_body_name = .Welle_1D_270.FLEX_BODY_1  &
   deformed_mode_number = 0  &
   display_only_deformed = yes
!
part modify flexible_body visual_representation  &
   flexible_body_name = .Welle_1D_270.FLEX_BODY_1  &
   scale_factor = 20.0
!
defaults coordinate_system  &
   default_coordinate_system = .Welle_1D_270.FLEX_BODY_1
!
! ****** Markers for current flexible body ******
!
undo begin_block suppress = yes
!
! IMPORTANT: Flexible body marker creation is grouped
! inside the same undo block for greater efficiency
!
marker create  &
   marker_name = .Welle_1D_270.FLEX_BODY_1.MARKER_1  &
   adams_id = 1  &
   node_id = 101  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .Welle_1D_270.FLEX_BODY_1.MARKER_3  &
   adams_id = 3  &
   node_id = 1  &
   orientation = 0.0d, 0.0d, 0.0d
!
undo end_block
!
part attributes  &
   flexible_body_name = .Welle_1D_270.FLEX_BODY_1  &
   color = MAIZE  &
   name_visibility = off
!
!----------------------------------- Joints -----------------------------------!
!
!
constraint create joint fixed  &
   joint_name = .Welle_1D_270.JOINT_1  &
   adams_id = 1  &
   i_marker_name = .Welle_1D_270.FLEX_BODY_1.MARKER_3  &
   j_marker_name = .Welle_1D_270.ground.MARKER_4
!
constraint attributes  &
   constraint_name = .Welle_1D_270.JOINT_1  &
   name_visibility = off
!
!----------------------------------- Forces -----------------------------------!
!
!
force create direct single_component_force  &
   single_component_force_name = .Welle_1D_270.SFORCE_1  &
   adams_id = 1  &
   type_of_freedom = translational  &
   i_marker_name = .Welle_1D_270.FLEX_BODY_1.MARKER_1  &
   j_marker_name = .Welle_1D_270.ground.MARKER_2  &
   action_only = on  &
   function = ""
!
!----------------------------- Simulation Scripts -----------------------------!
!
!
simulation script create  &
   sim_script_name = .Welle_1D_270.Last_Sim  &
   commands =   &
              "simulation single_run transient type=auto_select initial_static=no end_time=1.0 number_of_steps=100 model_name=.Welle_1D_270"
!
!------------------------------ Dynamic Graphics ------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Welle_1D_270.ground
!
geometry create shape force  &
   force_name = .Welle_1D_270.SFORCE_1_force_graphic_1  &
   adams_id = 1  &
   force_element_name = .Welle_1D_270.SFORCE_1  &
   applied_at_marker_name = .Welle_1D_270.FLEX_BODY_1.MARKER_1
!
!---------------------------------- Accgrav -----------------------------------!
!
!
force create body gravitational  &
   gravity_field_name = gravity  &
   x_component_gravity = 0.0  &
   y_component_gravity = -9806.65  &
   z_component_gravity = 0.0
!
force attributes  &
   force_name = .Welle_1D_270.gravity  &
   active = off
!
!----------------------------- Analysis settings ------------------------------!
!
!
!---------------------------------- Measures ----------------------------------!
!
!
measure create point  &
   measure_name = .Welle_1D_270.INT_NODE_1_Y_direction  &
   point = .Welle_1D_270.FLEX_BODY_1.INT_NODE_1  &
   characteristic = translational_displacement  &
   component = y_component
!
data_element attributes  &
   data_element_name = .Welle_1D_270.INT_NODE_1_Y_direction  &
   color = WHITE
!
measure create point  &
   measure_name = .Welle_1D_270.INT_NODE_101_Y_direction  &
   point = .Welle_1D_270.FLEX_BODY_1.INT_NODE_101  &
   characteristic = translational_displacement  &
   component = y_component
!
data_element attributes  &
   data_element_name = .Welle_1D_270.INT_NODE_101_Y_direction  &
   color = WHITE
!
!---------------------------- Function definitions ----------------------------!
!
!
force modify direct single_component_force  &
   single_component_force_name = .Welle_1D_270.SFORCE_1  &
   function = "-300"
!
!--------------------------- Expression definitions ---------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = ground
!
material modify  &
   material_name = .Welle_1D_270.steel  &
   youngs_modulus = (2.07E+011(Newton/meter**2))  &
   density = (7801.0(kg/meter**3))
!
geometry modify shape force  &
   force_name = .Welle_1D_270.SFORCE_1_force_graphic_1  &
   applied_at_marker_name = (.Welle_1D_270.SFORCE_1.i)
!
model display  &
   model_name = Welle_1D_270
